ColorSpace

Enum ColorSpace 

pub enum ColorSpace {
    Xyz,
    Lab,
    Luv,
    YCbCr,
    Yxy,
    Rgb,
    Gray,
    Hsv,
    Hls,
    Cmyk,
    Cmy,
}
A color space signature, used for both the data color space and the profile connection space (ICC.1:2022 7.2.6–7.2.7). Only the common spaces are listed; the multi-channel nCLR spaces are added in the implementation phase.

Variants



Xyz

'XYZ ' — CIE XYZ (a valid PCS).



Lab

'Lab ' — CIE L*a*b* (a valid PCS).



Luv

'Luv ' — CIE L*u*v*.



YCbCr

'YCbr' — YCbCr.



Yxy

'Yxy ' — CIE Yxy.



Rgb

'RGB ' — RGB.



Gray

'GRAY' — grayscale.



Hsv

'HSV ' — HSV.



Hls

'HLS ' — HLS.



Cmyk

'CMYK' — CMYK.



Cmy

'CMY ' — CMY.